Libvirt
=======

This workspace contains the basic tasks for provisioning and teardown of libvirt clusters

libvirt-new
===========
Provisions a new libvirt vm

libvirt-network
===============
Creates a new libvirt network

libvirt-storage
==============
Provisions a new libvirt vm with attached storage

libvirt-custom-img
==================
Provision a libvirt instances with a custom image
